@@ -36,6 +36,12 @@ def action(ns, series):
         series = [series]
 
     for s in series:
+        if s['status'] == u'Ended' and not ns.force:
+            ns.out(ns.t.bold_cyan(
+                u"Skipping: {0} (ended, use -f to force)".format(
+                    s['series_name'])))
+            continue
+
         ns.out(ns.t.bold_cyan(
             u"Syncing: {0}".format(s['series_name'])))
 
@@ -48,6 +54,14 @@ def action(ns, series):
 
 
 def setup(parser):
+    parser.add_argument(
+        "-f", "--force",
+        default=False,
+        help="Sync a series, even if it has ended.",
+        action='store_const',
+        const=True,
+    )
+
     parser.add_argument(
         "series_query",
         metavar="<name|id>",
